
function toHHMMSS(secs)
{
	var hours   = Math.floor(secs / 3600);
	var minutes = Math.floor((secs - (hours * 3600)) / 60);
	var seconds = Math.floor(secs - (hours * 3600) - (minutes * 60));

	if (hours < 10) hours = "0" + hours;
	if (minutes < 10) minutes = "0" + minutes;
	if (seconds < 10) seconds = "0" + seconds;
	return hours + ':' + minutes + ':' +seconds;
}

// Handle for the progress bar update event
var handle = 0;

// Data used for calculating ETA
//  Job start time
var start = 0;
//  Current estimate of total length
var est = 0;
//  Last percentage complete seen
var lastper = 0;

// Update the progress bar
function update_progressbar()
{
	$.get('progress.jim' + '?file=' + file,
	    function(data) {
		if (handle)
		{
			$('#progressbar').reportprogress(data);
			// If the percentage has changed, recalculate the
			// ETA.
			if (data > lastper)
			{
				est = ($.now() - start) / data * 100;
				lastper = data;
			}
			// Update the remaining expected run time
			if (est)
			{
				var rem = est - ($.now() - start);
				if (rem > 0)
					$('#est').html(toHHMMSS(rem / 1000));
				else
					$('#est').html('almost done...');
			}
		}
	});
}

$(function() {
// This block is run when the whole page has loaded.

// Enable or disable the Run button depending on the checkbox status
function reset_run()
{
	// If any checkboxes are checked
	if ($('input:checkbox:checked').length > 0)
	{
		$('#run').button('enable');
		$('#runnote').slideUp('slow');
	}
	else
	{
		$('#run').button('disable');
		$('#runnote').slideDown('slow');
	}
}

// Incremental AJAX callback

function loaddata(data, isfinal) {
	if (isfinal)
	{
		$('#results_inner').text(data);
		$('#est').html('done...');
	}
	else
		$('#results_inner').append(data);
}

// Skin the back button and attach a click handler that goes back to the
// media browser.
$('#back').button({
	icons : {
		primary : "ui-icon-arrowreturnthick-1-w"
	}
}).on('click', function() {
	window.location = '/browse/index.jim?dir=' +
	    encodeURIComponent(dir);
});

// Skin the info button and attach a click handler.
$('#info').button({
	icons : {
		primary : "ui-icon-play"
	}
}).on('click', function() {
	// Prevent double click
	$(this).button('disable');
	// Prevent run button being clicked	
	$('#run').button('disable');
	// Hide the run note
	$('#runnote').slideUp('fast');
	
	// Load form data into an object
	var formdata = $('#sidecarform').serializeArray();
	if (!formdata.length)
	{
		alert('Error loading form data');
		return;
	}
    // Spinner not required
	$('.running').addClass('hidden');
	// Show the results pane
	$('#results').removeClass('hidden').show();
	// Clear the results pane
	$('#results_inner').empty();

	// Iterate the form data to build the data that will be submitted
	// to the backend script
	var data = {'file': file};
	$.each(formdata, function(k, v) {
		data[v.name] = v.value
	});
	
	// Incremental ajax request to do the work
	$.ajax({
		type: "GET",
		url: 'getinfo.jim',
		data: data,
		success: function(data) {
			loaddata(data, true);
		},
		error : function(_, _, e) {
			if (window.console)
				console.log("ajax error");
			alert(e);
		}
	});
	
});

// Skin the run button and attach a click handler
$('#run').button({
	icons : {
		primary : "ui-icon-play"
	}
});
// Use delegated event for the run button as it gets disabled and
// enabled.
$('#buttons').on('click', '#run', function() {
	// Prevent double click
	$(this).button('disable');
	// Prevent info  and back buttons being clicked	
	$('#info').button('disable');
    $('#back').button('disable');	
	// Load form data into an object
	var formdata = $('#sidecarform').serializeArray();
	if (!formdata.length)
	{
		alert('Error loading form data');
		return;
	}

	// Disable the form inputs
	// (after serialising or it won't retrieve anything)
	$('form input').disable();

	// Initialise the progress bar
	$('#progressbar').reportprogress(0);

	// Show the results pane
	$('#results').removeClass('hidden').show();
	// Show the spinner
	$('.running').slideDown('slow');
	// Clear the results pane
	$('#results_inner').empty();

	// Iterate the form data to build the data that will be submitted
	// to the backend script
	var data = {'file': file};
	$.each(formdata, function(k, v) {
		data[v.name] = v.value
	});

	start = $.now();
	// Update the progress bar every second.
	handle = setInterval("update_progressbar()", 1000);

	// Incremental ajax request to do the work
	$.ajax({
		type: "GET",
		url: 'execute.jim',
		data: data,
		progress: loaddata,
		progressInterval: 1000,
		timeout: 86400000,
		success: function(data) {
			// Hide spinner
			$('#progressbar').reportprogress(100);
			$('.running').slideUp('slow');
			// Cancel the progress bar update event
			clearInterval(handle);
			handle = 0;
			loaddata(data, true);
			$('#back').button('enable');
		},
		error : function(_, _, e) {
			if (window.console)
				console.log("ajax error");
			// Hide spinner
			$('.running').slideUp('slow');
			alert(e);
			$('#back').button('enable');
		}
	});

});

// Call reset_run on page load, but after the buttons are initialised
reset_run();

// Call reset_run whenever the value of a checkbox changes
$('input:checkbox').on('change', reset_run);

// End block run following complete page load.
});

